@@ -413,7 +413,7 @@ int PQCSettings::migrate(QString oldversion) {
     /*************************************************************************/
 
     QStringList versions;
-    versions << "4.0" << "4.1" << "4.2" << "4.3" << "4.4";
+    versions << "4.0" << "4.1" << "4.2" << "4.3" << "4.4" << "4.5";
     // when removing the 'dev' value, check below for any if statement involving 'dev'!
 
     // this is a safety check to make sure we don't forget the above check
@@ -488,6 +488,63 @@ int PQCSettings::migrate(QString oldversion) {
 
             }
 
+        } else if(curVer == "4.5") {
+
+            // update slideshow music settings
+            QSqlQuery query(db);
+
+            if(!query.exec("SELECT `value` FROM `slideshow` WHERE `name`='MusicFile'"))
+                qCritical() << "Unable to get current MusicFile value:" << query.lastError().text();
+            else {
+
+                query.next();
+
+                QString val = query.value(0).toString();
+
+                if(val != "") {
+
+                    QSqlQuery queryUpdate(db);
+                    queryUpdate.prepare("UPDATE `slideshow` SET `value`=:val WHERE `name`='MusicFiles'");
+                    queryUpdate.bindValue(":val", val);
+                    if(!queryUpdate.exec())
+                        qCritical() << "ERROR updating MusicFile value:" << queryUpdate.lastError().text();
+                    queryUpdate.clear();
+
+                }
+
+                query.clear();
+
+            }
+
+            // update name for modal settings
+            const QStringList renameModalSettings = {"PopoutFileDialog", "PopoutMapExplorer"};
+
+            for(auto &s : renameModalSettings) {
+
+                QSqlQuery queryRename(db);
+                if(!queryRename.exec(QString("Update `interface` SET `name`='%1NonModal' WHERE `name`='%2KeepOpen'").arg(s, s)))
+                    qCritical() << ("Unable to rename modal settings name '" + s + "':") << query.lastError().text();
+
+                queryRename.clear();
+
+            }
+
+            // update name for filwtypes settings
+            const QStringList renameFiletypeSettings = {"CheckForPhotoSphere", "PhotoSphereAutoLoad"};
+
+            for(int i = 0; i < renameFiletypeSettings.length()/2; ++i) {
+
+                QString oldSetting = renameFiletypeSettings[2*i +0];
+                QString newSetting = renameFiletypeSettings[2*i +1];
+
+                QSqlQuery queryRename(db);
+                if(!queryRename.exec(QString("Update `filetypes` SET `name`='%1' WHERE `name`='%2'").arg(newSetting, oldSetting)))
+                    qCritical() << ("Unable to rename filetypes settings name '" + oldSetting + "' to '" + newSetting + "':") << query.lastError().text();
+
+                queryRename.clear();
+
+            }
+
         }
 
         ////////////////////////////////////
