@@ -367,6 +367,8 @@ void PQCShortcuts::saveAllCurrentShortcuts(QVariantList list) {
 
 void PQCShortcuts::closeDatabase() {
 
+    qDebug() << "";
+
     if(dbIsTransaction) {
         db.commit();
         dbIsTransaction = false;
@@ -423,7 +425,7 @@ bool PQCShortcuts::migrate(QString oldversion) {
     /*************************************************************************/
 
     QStringList versions;
-    versions << "4.0" << "4.1" << "4.2" << "4.3" << "4.4";
+    versions << "4.0" << "4.1" << "4.2" << "4.3" << "4.4" << "4.5";
     // when removing the 'dev' value, check below for any if statement involving 'dev'!
 
     // this is a safety check to make sure we don't forget the above check
