@@ -184,24 +184,24 @@ int PQCNotify::getStartupCheck() {
     return m_startupCheck;
 }
 
-void PQCNotify::setInsidePhotoSphere(bool val) {
-    if(val != m_insidePhotoSphere) {
-        m_insidePhotoSphere = val;
-        Q_EMIT insidePhotoSphereChanged();
+void PQCNotify::setShowingPhotoSphere(bool val) {
+    if(val != m_showingPhotoSphere) {
+        m_showingPhotoSphere = val;
+        Q_EMIT showingPhotoSphereChanged();
     }
 }
-bool PQCNotify::getInsidePhotoSphere() {
-    return m_insidePhotoSphere;
+bool PQCNotify::getShowingPhotoSphere() {
+    return m_showingPhotoSphere;
 }
 
-void PQCNotify::setHasPhotoSphere(bool val) {
-    if(val != m_hasPhotoSphere) {
-        m_hasPhotoSphere = val;
-        Q_EMIT hasPhotoSphereChanged();
+void PQCNotify::setIsMotionPhoto(bool val) {
+    if(val != m_isMotionPhoto) {
+        m_isMotionPhoto = val;
+        Q_EMIT isMotionPhotoChanged();
     }
 }
-bool PQCNotify::getHasPhotoSphere() {
-    return m_hasPhotoSphere;
+bool PQCNotify::getIsMotionPhoto() {
+    return m_isMotionPhoto;
 }
 
 void PQCNotify::setBarcodeDisplayed(bool val) {
