@@ -224,7 +224,7 @@ bool PQCScriptsConfig::exportConfigTo(QString path) {
     // handler to the file
     struct archive *a = archive_write_new();
 
-    // Write a zip file with gzip compression
+    // Write a zip file
     archive_write_add_filter_gzip(a);
     archive_write_set_format_zip(a);
 
@@ -280,7 +280,7 @@ bool PQCScriptsConfig::exportConfigTo(QString path) {
 
 }
 
-bool PQCScriptsConfig::importConfigFrom(QString path, bool reloadData) {
+bool PQCScriptsConfig::importConfigFrom(QString path) {
 
     qDebug() << "args: path =" << path;
 
@@ -312,14 +312,12 @@ bool PQCScriptsConfig::importConfigFrom(QString path, bool reloadData) {
     // Create new archive handler
     struct archive *a = archive_read_new();
 
-    // We allow any type of compression and format
+    // Read config file
+    archive_read_support_format_all(a);
     archive_read_support_filter_all(a);
-    archive_read_support_format_zip(a);
 
-    // Read file
+    // Read file - if something went wrong, output error message and stop here
     int r = archive_read_open_filename(a, archiveFile.toLocal8Bit().data(), 10240);
-
-    // If something went wrong, output error message and stop here
     if(r != ARCHIVE_OK) {
         qWarning() << "ERROR: archive_read_open_filename() returned code of" << r;
         return false;
@@ -335,55 +333,43 @@ bool PQCScriptsConfig::importConfigFrom(QString path, bool reloadData) {
 
         if(allfiles.contains(filenameinside)) {
 
-            // Find out the size of the data
-            size_t size = archive_entry_size(entry);
-
-            // Create a uchar buffer of that size to hold the data
-            uchar *buff = new uchar[size+1];
-
-            // And finally read the file into the buffer
-            int r = archive_read_data(a, (void*)buff, size);
-            if(r != (int)size) {
-                qWarning() << QString("ERROR: Unable to extract file '%1':").arg(allfiles[filenameinside]) << archive_error_string(a) << "- Skipping file!";
-                continue;
-            }
-            // libarchive does not add a null terminating character, but Qt expects it, so we need to add it on
-            buff[size] = '\0';
+            // store read data in here
+            const void *buff;
+            size_t size;
+            la_int64_t offset;
 
             // The output file...
             QFile file(allfiles[filenameinside]);
             // Overwrite old content
-            if(file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-                file.write(reinterpret_cast<const char*>(buff), size+1);
-                file.close();
-            } else
+            if(!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
                 qWarning() << QString("ERROR: Unable to write new config file '%1'... Skipping file!").arg(allfiles[filenameinside]);
+                continue;
+            }
+            QDataStream out(&file);   // we will serialize the data into the file
 
-            delete[] buff;
+            // read data
+            while((r = archive_read_data_block(a, &buff, &size, &offset)) == ARCHIVE_OK) {
+                if(r != ARCHIVE_OK || size == 0) {
+                    qWarning() << QString("ERROR: Unable to extract file '%1':").arg(allfiles[filenameinside]) << archive_error_string(a) << " " << QString("(%1)").arg(r) << " - Skipping file!";
+                    break;
+                }
+                out.writeRawData((const char*) buff, size);
+            }
+
+            file.close();
 
         }
 
     }
 
     // Close archive
+    r = archive_read_close(a);
+    if(r != ARCHIVE_OK)
+        qWarning() << "ERROR: archive_read_close() returned code of" << r;
     r = archive_read_free(a);
     if(r != ARCHIVE_OK)
         qWarning() << "ERROR: archive_read_free() returned code of" << r;
 
-    // reload settings, shortcuts, and imageformats
-    // we only reload when config was exported to default folders
-    // we don't need to reload the contextmenu, the filewatcher takes care of that
-    if(reloadData) {
-
-        PQCSettings::get().readDB();
-        PQCShortcuts::get().readDB();
-        PQCImageFormats::get().readDatabase();
-
-        PQCValidate validate;
-        validate.validate();
-
-    }
-
     return true;
 
 #endif
