@@ -203,12 +203,12 @@ QStringList PQCScriptsImages::listArchiveContent(QString path, bool insideFilena
 
                 if(insideFilenameOnly) {
                     for(const QString &f : std::as_const(allfiles)) {
-                        if(PQCImageFormats::get().getEnabledFormats().contains(QFileInfo(f).suffix()))
+                        if(PQCImageFormats::get().getEnabledFormats().contains(QFileInfo(f).suffix().toLower()))
                             ret.append(f);
                     }
                 } else {
                     for(const QString &f : std::as_const(allfiles)) {
-                        if(PQCImageFormats::get().getEnabledFormats().contains(QFileInfo(f).suffix()))
+                        if(PQCImageFormats::get().getEnabledFormats().contains(QFileInfo(f).suffix().toLower()))
                             ret.append(QString("%1::ARC::%2").arg(f, path));
                     }
                 }
@@ -253,7 +253,7 @@ QStringList PQCScriptsImages::listArchiveContent(QString path, bool insideFilena
             QString filenameinside = QString::fromWCharArray(archive_entry_pathname_w(entry));
 
             // If supported file format, append to temporary list
-            if((PQCImageFormats::get().getEnabledFormats().contains(QFileInfo(filenameinside).suffix())))
+            if((PQCImageFormats::get().getEnabledFormats().contains(QFileInfo(filenameinside).suffix().toLower())))
                 allfiles.append(filenameinside);
 
         }
@@ -748,9 +748,6 @@ bool PQCScriptsImages::isPhotoSphere(QString path) {
 
 #ifdef PQMPHOTOSPHERE
 
-    if(!PQCSettings::get()["filetypesCheckForPhotoSphere"].toBool())
-        return false;
-
 #if defined(PQMEXIV2) && defined(PQMEXIV2_ENABLE_BMFF)
 
 #if EXIV2_TEST_VERSION(0, 28, 0)
@@ -963,7 +960,7 @@ bool PQCScriptsImages::isSVG(QString path) {
 
     qDebug() << "args: path =" << path;
 
-    const QString suffix = QFileInfo(path).suffix();
+    const QString suffix = QFileInfo(path).suffix().toLower();
     return (suffix == "svg" || suffix == "svgz");
 
 }
@@ -1565,10 +1562,19 @@ bool PQCScriptsImages::applyColorSpaceQt(QImage &img, QString filename, QColorSp
 #ifdef PQMLCMS2
 bool PQCScriptsImages::applyColorSpaceLCMS2(QImage &img, QString filename, cmsHPROFILE targetProfile) {
 
-    int lcms2format = PQCScriptsImages::get().toLcmsFormat(img.format());
+    int lcms2SourceFormat = PQCScriptsImages::get().toLcmsFormat(img.format());
+
+    QImage::Format targetFormat = img.format();
+    // this format causes problems with lcms2
+    // no error is caused but the resulting image is fully transparent
+    // removing the alpha channel seems to fix this
+    if(img.format() == QImage::Format_ARGB32)
+        targetFormat = QImage::Format_RGB32;
+    int lcms2targetFormat = PQCScriptsImages::get().toLcmsFormat(img.format());
+
 
     // Create a transformation from source (sRGB) to destination (provided ICC profile) color space
-    cmsHTRANSFORM transform = cmsCreateTransform(cmsCreate_sRGBProfile(), lcms2format, targetProfile, lcms2format, INTENT_PERCEPTUAL, 0);
+    cmsHTRANSFORM transform = cmsCreateTransform(targetProfile, lcms2SourceFormat, cmsCreate_sRGBProfile(), lcms2targetFormat, INTENT_PERCEPTUAL, 0);
     if (!transform) {
         // Handle error, maybe close profile and return original image or null image
         cmsCloseProfile(targetProfile);
@@ -1576,7 +1582,7 @@ bool PQCScriptsImages::applyColorSpaceLCMS2(QImage &img, QString filename, cmsHP
         return false;
     } else {
 
-        QImage ret(img.size(), img.format());
+        QImage ret(img.size(), targetFormat);
         ret.fill(Qt::transparent);
         // Perform color space conversion
         cmsDoTransform(transform, img.constBits(), ret.bits(), img.width() * img.height());
@@ -1674,3 +1680,23 @@ QString PQCScriptsImages::detectVideoColorProfile(QString path) {
     return "";
 
 }
+
+void PQCScriptsImages::removeThumbnailFor(QString path) {
+
+    qDebug() << "args: path =" << path;
+
+    QByteArray p = QUrl::fromLocalFile(path).toString().toUtf8();
+
+    const QStringList cachedirs = {"xx-large",
+                                   "x-large",
+                                   "large",
+                                   "normal"};
+
+    for(auto &c : cachedirs) {
+        const QByteArray md5 = QCryptographicHash::hash(p,QCryptographicHash::Md5).toHex();
+        const QString thumbcachepath = PQCConfigFiles::GENERIC_CACHE_DIR() + "/thumbnails/" + c + "/" + md5 + ".png";
+        if(QFileInfo::exists(thumbcachepath))
+            QFile::remove(thumbcachepath);
+    }
+
+}
